@@ -16,8 +16,8 @@
 #' @param engine The preferred processing functions from either one of "zonal",
 #'   "extract" or "exactextract" as character.
 #' @keywords indicator
-#' @returns A function that returns a tibble with a column for each specified
-#'   stats and a column with the respective date.
+#' @returns A function that returns an indicator tibble with specified drought
+#'   indicator statistics as variable and corresponding values as value.
 #' @include register.R
 #' @export
 #' @examples
@@ -75,11 +75,11 @@ calc_drought_indicator <- function(engine = "extract", stats = "mean") {
     )
 
     dates <- sub(".*(\\d{8}).*", "\\1", names(nasa_grace))
-    dates <- as.Date(dates, format = "%Y%m%d")
+    dates <- as.POSIXct(paste0(as.Date(dates, "%Y%m%d"), "T00:00:00Z"))
 
     prep_results <- function(result, datetimes) {
       result %>%
-        dplyr::mutate(datetime = datetimes, unit = "dimensionless") %>%
+        dplyr::mutate(datetime = datetimes, unit = "percentage") %>%
         tidyr::pivot_longer(cols = -c(datetime, unit), names_to = "variable") %>%
         dplyr::select(datetime, variable, unit, value)
     }
