@@ -10,7 +10,7 @@
 #'
 #' @name teow
 #' @keywords resource
-#' @returns  A function that returns a character of file paths.
+#' @returns  A function that returns an `sf` footprint object.
 #' @references Olson, D. M., Dinerstein, E., Wikramanayake, E. D., Burgess, N. D.,
 #' Powell, G. V. N., Underwood, E. C., D’Amico, J. A., Itoua, I., Strand, H. E.,
 #' Morrison, J. C., Loucks, C. J., Allnutt, T. F., Ricketts, T. H., Kura, Y., Lamoreux,
@@ -25,44 +25,18 @@ get_teow <- function() {
            name = "teow",
            type = "vector",
            outdir = mapme_options()[["outdir"]],
-           verbose = mapme_options()[["verbose"]],
-           testing = mapme_options()[["testing"]]) {
-    filename <- file.path(outdir, "wwf_terr_ecos.gpkg")
-    # check if output file exists
-    if (file.exists(filename)) {
-      return(filename)
-    }
-
-    # get url
-    url <- paste("https://files.worldwildlife.org/wwfcmsprod/files/",
-      "Publication/file/6kcchn7e3u_official_teow.zip",
+           verbose = mapme_options()[["verbose"]]) {
+    url <- paste(
+      "/vsizip//vsicurl/",
+      "https://files.worldwildlife.org/wwfcmsprod/files/",
+      "Publication/file/6kcchn7e3u_official_teow.zip/",
+      "official/wwf_terr_ecos.shp",
       sep = ""
     )
-    # start download in a temporal directory within rundir
-    downloads <- tryCatch(
-      {
-        download.file(url,
-          file.path(outdir, basename(paste0("TEOW_global.zip"))),
-          quiet = TRUE
-        )
-      },
-      error = function(e) e,
-      warning = function(e) e
-    )
-    if (inherits(downloads, "error")) stop(downloads)
-    # unzip
-    unzip_and_remove(file.path(outdir, "TEOW_global.zip"), outdir)
-    # load shp
-    shp <- read_sf(file.path(outdir, "official/wwf_terr_ecos.shp"))
-    # write as gpkg
-    write_sf(shp, file.path(outdir, "wwf_terr_ecos.gpkg"))
-    # remove all except desired layers
-    all_files <- list.files(outdir, full.names = T)
-    unlink(grep(paste0("wwf_terr_ecos.gpkg"), all_files, value = T, invert = T),
-      recursive = T, force = T
-    )
-    # return paths to the gpkg
-    filename
+    bbox <- c(xmin = -180.0, ymin = -90.0, xmax = 180.0, ymax = 84.0)
+    tile <- st_as_sf(st_as_sfc(st_bbox(bbox, crs = "EPSG:4326")))
+    tile[["source"]] <- url
+    make_footprints(tile, filenames = "wwf_terr_ecos.gpkg", what = "vector")
   }
 }
 
