@@ -207,6 +207,7 @@ portfolio_wide <- function(x, indicators = NULL, drop_geoms = FALSE) {
 
 .check_portfolio <- function(x, verbose = mapme_options()[["verbose"]]) {
   stopifnot(inherits(x, "sf"))
+  sf_col <- attr(x, "sf_column")
 
   if (st_crs(x) != st_crs(4326)) {
     message("CRS of x is not EPSG:4326. Attempting to transform.")
@@ -229,6 +230,7 @@ portfolio_wide <- function(x, indicators = NULL, drop_geoms = FALSE) {
     message(msg)
     x[["assetid"]] <- 1:nrow(x)
   }
+  st_geometry(x) <- sf_col
   x
 }
 
